#Requires -Modules 'ActiveDirectory'
Param(
    [Parameter(Mandatory)]
    [hashtable]$Parameter
)

# Only executed on primary Domain Controller
If ((Get-WmiObject -Class 'Win32_ComputerSystem').DomainRole -eq 5) {
    $GetContentSplat = @{
        Path = "$($PSScriptRoot)\$($MyInvocation.MyCommand)".Replace('.ps1', ".csv")
    }
    $CSVImport = (Get-Content @GetContentSplat) | ConvertFrom-Csv

    ForEach ($User in $CSVImport) {
        # Create new user
        $NewADUserSplat = @{
            Name            = ($User.DistinguishedName -split ',', 2)[0].Substring(3)
            Path            = ($User.DistinguishedName -split ',', 2)[1] + ',DC=' + $Parameter['addsconfig.domainname'].Replace('.', ',DC=')
            AccountPassword = ConvertTo-SecureString $User.Password -AsPlainText -Force
            PassThru        = $True
            ErrorAction     = 'SilentlyContinue'
        }
        $NewADUser = New-ADUser @NewADUserSplat
        # Add user to group(s)
        If ($User.MemberOf -ne '') {
            ForEach ($Group in $User.MemberOf.Split('|')) {
                $AddADGroupMemberSplat = @{
                    Identity    = $Group + ',DC=' + $Parameter['addsconfig.domainname'].Replace('.', ',DC=')
                    Members     = $NewADUser.DistinguishedName
                    ErrorAction = 'SilentlyContinue'
                }
                Add-ADGroupMember @AddADGroupMemberSplat
            }
        }
        # Enable user
        $EnableADAccountSplat = @{
            Identity    = $NewADUser.DistinguishedName
            ErrorAction = 'Continue'
        }
        Enable-ADAccount @EnableADAccountSplat
    }
}